@@ -21,6 +21,7 @@ TW_AUTHOR="[@]pkgauthor[@]"
 TW_DESCRIPTION="[@]pkgdescription[@]"
 TW_BUGREPORT="[@]pkgbugreport[@]"
 TW_DATADIR="[@]pkgdatadir[@]"
+TW_VERSION="[@]pkgversion[@]"
 
 function tw_info
 {
@@ -29,7 +30,7 @@ function tw_info
 
 function tw_error
 {
-	echo "$TW: $@"; tw_info; exit 1
+	echo "$TW: $@" >&2; tw_info >&2; exit 1
 }
 
 function tw_usage
@@ -48,7 +49,7 @@ function tw_usage
 
 function tw_version
 {
-	printf "[@]pkgversion[@]\n"
+	printf "$TW_VERSION\n"
 	exit 0
 }
 
